# comment out when not a pre-release
#define prel    rc1

%define rel     6

Name:           gpick
Version:        0.2.6
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Summary:        Advanced color picker written in C++ using GTK+ toolkit
License:        BSD
Group:          Graphics/Utilities
URL:            https://github.com/thezbyg/gpick/
Source0:        https://github.com/thezbyg/gpick/archive/%{name}-%{version}%{?prel:%prel}.tar.gz
Patch1:		gpick-0.2.6-link-expat.patch
Patch2:		gpick-0.2.6-linking.patch
BuildRequires:	cmake
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  boost-devel
BuildRequires:  flex
BuildRequires:  ragel

%description
Gpick is an advanced color picker written in C++ using GTK+ toolkit.
Its main features are:
    - Create palettes from images
    - Color scheme creation tools
    - Fast color picking
    - Magnification
    - Colors automatically named
        + Closest color name is found using CIE94 color difference function,
          which is closer to the way humans interpret color differences, than
          difference of red, green and blue color amounts
    - Export to following formats
        + Inkscape/Gimp Palette (*.gpl)
        + Adobe Swatch Exchange (*.ase)
        + Alias/WaveFront Material (*.mtl)
    - Import from following formats:
        + Inkscape/Gimp Palette (*.gpl)
        + Adobe Swatch Exchange (*.ase)
    - Picked colors can be copied to clipboard in multiple formats
        + Hexadecimal notation - #rrggbb
        + Functional RGB notation - rgb(red, green, blue)
        + Functional HSL notation - hsl(hue, saturation, lightness)
        + Custom conversions can be done, but requires some Lua language
          knowledge
    - Oversampling with five falloff types
        + Multiple pixel values are averaged to help picking colors from
          sources with noise, patterns and etc, where each pixel is different
          and overall color is produced by different amounts of particular
          color
    - Mix two or more colors using variable number of steps and different
      mixing types
    - Create lightness and/or saturation variations
    - Create harmonious colors
    - Create color schemes

%prep
%autosetup -n %{name}-%{name}-%{version}%{?prel:%prel} -p1

# Delete external libraries and only use system dependencies to build GPick
rm -rf extern
echo "INTERNAL_EXPAT=False" >> user-config.py
echo "INTERNAL_LUA=False" >> user-config.py
echo "LOCALEDIR=\"%{_datadir}/locale\"" >> user-config.py

%build
%cmake -DCMAKE_SKIP_RPATH:BOOL=ON
%cmake_build

%install
%cmake_install

# needs to be installed by hand
mkdir -p %{buildroot}%{_libdir}/%{name}
install -p -m 755 -t %{buildroot}%{_libdir}/%{name} %{_vpath_builddir}/*.so

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/gpick-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

rm -rf %{buildroot}%{_docdir}/%{name}

%find_lang %{name}

%files -f %{name}.lang
%doc README.md
%license LICENSE.txt
%{_bindir}/gpick
%{_datadir}/applications/gpick.desktop
%{_datadir}/mime/packages/gpick.xml
%{_metainfodir}/gpick.appdata.xml
%{_datadir}/gpick/
%{_iconsdir}/hicolor/*/apps/gpick.*
%{_mandir}/man1/gpick.1*

%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so
%{_sysconfdir}/ld.so.conf.d/gpick-%{_arch}.conf


%changelog
* Sat Dec 24 2022 wally <wally> 0.2.6-6.mga9
+ Revision: 1926476
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 0.2.6-5.mga9
+ Revision: 1867255
- rebuild for boost 1.79.0

* Wed Mar 30 2022 umeabot <umeabot> 0.2.6-4.mga9
+ Revision: 1835691
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 0.2.6-3.mga9
+ Revision: 1762632
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 0.2.6-2.mga9
+ Revision: 1744689
- skip RPATH when building
- ensure system expat and lua is used
- rebuild for boost 1.77.0

* Sat May 15 2021 wally <wally> 0.2.6-1.mga9
+ Revision: 1723864
- new version 2.6.0
- switch to cmake build
- rebuild for boost 1.76.0

* Sat Apr 03 2021 wally <wally> 0.2.6-0.rc1.8.mga9
+ Revision: 1712920
- rebuild for lua 5.4

* Thu Dec 31 2020 wally <wally> 0.2.6-0.rc1.7.mga8
+ Revision: 1666764
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.2.6-0.rc1.6.mga8
+ Revision: 1662006
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 0.2.6-0.rc1.5.mga8
+ Revision: 1578059
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.2.6-0.rc1.4.mga8
+ Revision: 1544753
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.2.6-0.rc1.3.mga8
+ Revision: 1483374
- rebuild for boost 1.72.0
- replace deprecated %%setup_compile_flags

* Sun Sep 29 2019 daviddavid <daviddavid> 0.2.6-0.rc1.2.mga8
+ Revision: 1447939
- port to GTk+3

* Sun Sep 29 2019 daviddavid <daviddavid> 0.2.6-0.rc1.1.mga8
+ Revision: 1447934
- new version: 0.2.6rc1
- switch build to python3-scons

* Fri Apr 05 2019 daviddavid <daviddavid> 0.2.5-8.mga7
+ Revision: 1385996
- switch to Python2 scons support

* Sun Sep 23 2018 umeabot <umeabot> 0.2.5-7.mga7
+ Revision: 1298047
- Mageia 7 Mass Rebuild

* Mon Feb 08 2016 umeabot <umeabot> 0.2.5-6.mga6
+ Revision: 944403
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.2.5-5.mga5
+ Revision: 742312
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.5-4.mga5
+ Revision: 679912
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.2.5-3.mga4
+ Revision: 529451
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 0.2.5-2.mga4
+ Revision: 451863
- rebuild for new boost

* Sun Jul 07 2013 wally <wally> 0.2.5-1.mga4
+ Revision: 450913
- new version 0.2.5
- use system lua and expat (from Fedora)
- clean .spec a bit

* Sat Jan 12 2013 umeabot <umeabot> 0.2.4-4.mga3
+ Revision: 352522
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 barjac <barjac> 0.2.4-3.mga3
+ Revision: 343266
- update group - again

* Wed Jan 02 2013 barjac <barjac> 0.2.4-2.mga3
+ Revision: 337845
- update group

* Wed Sep 14 2011 obgr_seneca <obgr_seneca> 0.2.4-1.mga2
+ Revision: 143536
- imported package gpick


* Fri Aug 19 2011 Oliver Burger <oliver.bgr@googlemail.com> 0.2.4-1.mga1
- initial build for Mageia
